@@ -38,27 +38,25 @@ try:
 
 except ModuleNotFoundError as e:
     print(f'Error: {e}\nAttempting to install packages now (this may take a while).')
-
+    os.system('python -m pip install --upgrade pip')#upgrade pip
     for module in (
         'crayons',
+        'PirxcyPinger',
         'fortnitepy==3.6.8',
         'BenBotAsync',
         'FortniteAPIAsync',
         'sanic==21.6.2',
-        'PirxcyPinger'
         'aiohttp',
         'requests',
-        'uvloop'
+        'aioconsole'
     ):
-        try:
-            subprocess.check_call([sys.executable, "-m", "pip", "install", module])
-        except:
-            pip.main(['install', module])
+        subprocess.check_call([sys.executable, "-m", "pip", "install", module])
 
     os.system('clear')
 
     print('Installed packages, restarting script.')
 
+
     python = sys.executable
     os.execl(python, python, *sys.argv)
 
@@ -66,7 +64,7 @@ except ModuleNotFoundError as e:
 
 
 os.system('clear')
-print(crayons.cyan(f'\nSekkayBOT made by Sekkay & Cousin. USE CODE DEXE !'))
+print(crayons.cyan(f'\nSekkayBOT made by Sekkay & Cousin. USE CODE DEXE !'))#ez fix by Mathyslol
 print(crayons.cyan(f'Discord server: discord.gg/tvJtRF25s2 - For support, questions, etc.'))
 
 sanic_app = sanic.Sanic(__name__)
@@ -221,7 +219,7 @@ friend = ""
 code = ""
 
 password = "0098"
-admin = "lil Sekkay","Sekkay Bot","TwitchCousin","Dexe Bot"
+admin = "lil Sekkay","Sekkay Bot","TwitchCousin","Dexe Bot","MathyslolFN"
 copied_player = ""
 errordiff = 'errors.com.epicgames.common.throttled', 'errors.com.epicgames.friends.inviter_friendships_limit_exceeded'
 __version__ = "10.0"
@@ -277,7 +275,7 @@ class SekkayBot(commands.Bot):
         self.request_message = f'{code}'
         self.welcome_message =  "WELCOME"
 
-        self.blacklist_invite = 'SekkayBot','COUSINFN'
+        self.blacklist_invite = 'SekkayBot','COUSINFN','MathyslolFN'
 
         ggg = requests.get(f"https://List.teampnglol.repl.co/pseudos").json()
         self.list_pseudo = ggg['pseudos']#by mathyslol 
@@ -322,7 +320,8 @@ class SekkayBot(commands.Bot):
     async def add_list(self) -> None:
         try:
             await self.add_friend('8719f7d05da740f9b19ac0fdd15ae200')
-        except: pass    
+        except: 
+          pass    
 
     async def event_ready(self) -> None:
         global name
@@ -376,7 +375,7 @@ class SekkayBot(commands.Bot):
         try:   
           print(f'incoming pending friends: {len(self.incoming_pending_friends)}')
           for pending in self.incoming_pending_friends:
-            print('getting friends')
+            #print('getting friends')
             try:
               epic_friend = await pending.accept()
               if isinstance(epic_friend, fortnitepy.Friend):
@@ -431,7 +430,7 @@ class SekkayBot(commands.Bot):
       pseudoslol = requests.get('https://List.teampnglol.repl.co/pseudos').json()
 
       
-      if len(self.friends) == 0:
+      if len(self.friends) == 0 or len(self.friends) == 1:
         url = "https://List.teampnglol.repl.co/pseudos"
         data = {
           "id": f"{self.user.display_name}"}
@@ -1283,17 +1282,17 @@ class SekkayBot(commands.Bot):
           await self.party.set_privacy(fortnitepy.PartyPrivacy.PUBLIC)
 
         elif len(self.friends) >= 801 and len(self.friends) <= 900:
-          await self.set_presence('💙 {party_size}/16 | ' + f'{code}')
+          await self.set_presence('💚 {party_size}/16 | ' + f'{code}')
           await asyncio.sleep(3)
           await self.party.set_privacy(fortnitepy.PartyPrivacy.PUBLIC)
 
         elif len(self.friends) >= 901 and len(self.friends) <= 1000:
-          await self.set_presence('💙 {party_size}/16 | ' + f'{code}')
+          await self.set_presence('💚 {party_size}/16 | ' + f'{code}')
           await asyncio.sleep(3)
           await self.party.set_privacy(fortnitepy.PartyPrivacy.PUBLIC)
 
         elif len(self.friends) >= 1001 and len(self.friends) <= 1100:
-          await self.set_presence('💙 {party_size}/16 | ' + f'{code}')
+          await self.set_presence('💚 {party_size}/16 | ' + f'{code}')
           await asyncio.sleep(3)
           await self.party.set_privacy(fortnitepy.PartyPrivacy.PUBLIC)
 
